@@ -509,7 +509,7 @@ $reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @ret
 $vals{1}{1}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
 # "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate", "apply_constraints"
 $vals{1}{1}{obs_modify} = 
 [   
 [ 
@@ -524,7 +524,7 @@ $vals{1}{1}{obs_modify} =
 $vals{1}{2}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
 # "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate", "apply_constraints"
 $vals{1}{2}{obs_modify} = 
 [   
 [ 
@@ -539,7 +539,7 @@ $vals{1}{2}{obs_modify} =
 $vals{1}{3}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "genchange"
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate", "apply_constraints"
 $vals{1}{3}{obs_modify} = 
 [   
 [ 
@@ -561,7 +561,7 @@ $vals{1}{3}{obs_modify} =
 $vals{1}{4}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "genchange"
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate", "apply_constraints"
 $vals{1}{4}{obs_modify} = 
 [   
 [ 
@@ -584,7 +584,7 @@ $vals{1}{4}{obs_modify} =
 $vals{1}{5}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "genchange"
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate", "apply_constraints"
 $vals{1}{5}{obs_modify} = 
 [   
 [ 
@@ -605,7 +605,7 @@ $vals{1}{5}{obs_modify} =
 $vals{1}{6}{applytype} = [ [ "rotate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "genchange"
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate", "apply_constraints"
 $vals{1}{6}{rotate} = 
 [ 
 [ "y", [ -90, 180 ], "c", "a" ],
@@ -619,7 +619,7 @@ $vals{1}{6}{rotate} =
 $vals{1}{7}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-# "change_groundreflectance", "genchange"
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate", "apply_constraints"
 $vals{1}{7}{change_groundreflectance} =  
 [ 
 [ 0.20, [ 0, 0.60 ] ] # [ base value, [ low_change, high_change ] ]; OR: [ base value, half-range ];
@@ -641,26 +641,6 @@ $vals{1}{7}{recalculateish} = [[ "y" ]];
 
 
 
-######################### PARAMETER 8. #############################
-
-#$vals{1}{8}{applytype} = [ [ "change_climate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
-## the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
-## "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-## "change_groundreflectance", "genchange"
-#$vals{1}{8}{general_variables} = 
-#[
-#"n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-#"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-#];
-#$vals{1}{8}{change_climate} = 
-#[
-#[ "../dbs/milan", "../dbs/cairo", "../dbs/glasgow" ]
-#]; # THE FULL PATH OF EACH FILE MUST BE SPECIFIED AND EACH FILE MUST ALREADY BE IN THE ESP-r FORMAT
-
-
-
-
-
 ############################################################################################################
 ####################### BEGINNING OF DATA FOR THE Sim::OPT::Takechance MODULE ##############################
 
@@ -957,75 +937,25 @@ $vals{1}{111}{reshape_windows} = [
 
 $vals{1}{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE MODEL AFTER A CERTAIN CHANGE; GENERAL. YOU HAVE TO WRITE A CONFIGURATION FILES TO DO IT. (SEE EXAMPLE MODELS.)
 [
+
 [ 
-["/zones/zone.geo"], # source file
-["/zones/zone.geo"], # target file
-["configfile.1.1.apply_constraints.pl"], # configuration file for constraints
-[216], # base values
-[ "/opts/default_configfile_control_constraints.pl" ], # swing values: still unused
-[ "e", "f", "g", "h", "0\nb\nb" , "0\nb\nd", "0\nb0\nb\nf", "0\nb\n0\nb\nh", "0\nb\n0\nb\nj" ], # letters of vertices in the esp-r geometry file. Here the letters have to be specified corresponding to the vertices whose position has to be changes through propagation of constraints.
-"y" # do you have long menus for items in ESP-r here? "y" or "n".
+[ "/zones/right.geo", "/zones/main.geo", ], # zone files #
+[ 2, 1 ], # zone file numbers - point to point correspondence with the names above
+[ "/zones/constraints2.pl" ], # configuration file for constraints
+[ 9 ], # [ increment_value1..., "increment value2" ]. It can be accessed by position with the variable "@val" in the file for propagation of constraints. 
+# Example: $val[0] is increment_value1, $val0 is increment value 2. 
 ],
+
 ]; 
-
-
-$vals{1}{111}{constrain_geometry} = # This is similar to "apply_constraints", but more general, because the propagation here criteria has to be specified in the configuration file. 
-[  
-[
-"/zones/zone.geo", # source file
-"/zones/zone.geo", # target file
-"/opts/default_configfile_geometry_constraints.pl", # configuration file for constraints. Here the criteria for propagation of constraints have to be specified.
-[ "k", "l", "m", "n" ], # vertex letters to be changed.
-"y", # long vertex letters (long menus) in ESP-r here? "y" or "n"
-[ 1, 1, 2, 1 ], # swings, corresponding point to point to vertexletters
-], # THIS IS THE FIRST OPERATION IN SERIES. OTHER CAN BE ADDED.
-]; #
-## THIS VARIABLE REGARDS GEOMETRY USER-IMPOSED CONSTRAINTS
-## THIS CONSTRAINT CONFIGURATION FILE MAKES AVAILABLE TO THE USER THE FOLLOWING VARIABLES:
-## @v[$number][$x], @v[$number][$y], @v[$number][$z]. 
-## EXAMPLE: @v[4][$x] = 1. THIS MEANS: COORDINATE x OF VERTEX 4. OR: @v[4][$x] =  @v[4][$y].
-## ALSO, IT FILE MAKES AVAILABLE TO THE USER INFORMATIONS ABOUT THE MORPHING STEP OF THE MODELS 
-## AND THE STEPS THE MODEL HAVE TO FOLLOW. SPECIFICALLY, THE FOLLOWING VARIABLES:
-## $stepsvar, WHICH TELLS THE PROGRAM HOW MANY ITERATION STEPS IT HAS TO DO IN THE CURRENT MORPHING PHASE.
-## $counterzone, WHICH TELLS THE PROGRAM WHAT OPERATION IS BEING EXECUTED IN THE CHAIN OF OPERATIONS 
-## THAT MAY BE EXECUTES AT EACH MORPHING PHASE. EACH $counterzone WILL CONTAIN ONE OR MORE ITERATION STEPS.
-## TYPICALLY, IT WILL BE USED FOR A ZONE, BUT NOTHING PREVENTS THAT SEVERAL OF THEM CHAINED ONE AFTER 
-## THE OTHER ARE APPLIED TO THE SAME ZONE.
-## $counterstep, WHICH TELLS THE PROGRAM WHAT THE CURRENT ITERATION STEP IS.
-## If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-## WITH THE FOLLOWING VARIABLE: @vertexletters
-
-$vals{1}{111}{constrain_obstructions} = # To apply constraints to and from obstructions.
-[ 
-[
-"a", # zone letter
-"/zones/zone.geo", # source file
-"/zones/zone.geo", # target file
-"/opts/default_configfile_obstruction_constraints.pl", # configuration file for constraints. Here the criteria for propagation of constraints have to be specified.
-[  "e", "f", "g", "h" ], # obstruction letters to be changed.
-"y" # act on construction too? "y" or "n". Note that constructions letters (as they appear in the construction database) and not construction names have to be given in the configuration files.
-], 
-];
-## THIS PART REGARDS USER-IMPOSED CONSTRAINTS ABOUT OBSTRUCTIONS
-## THIS CONSTRAINT CONFIGURATION FILE FILE MAKES AVAILABLE TO THE USER THE FOLLOWING VARIABLES:
-## $obs[$obs_number][$x], $obs[$obs_number][$y], $obs[$obs_number][$y]
-## $obs[$obs_number][$width], $obs[$obs_number][$depth], $obs[$obs_number][$height]
-## $obs[$obs_number][$z_rotation], $obs[$obs_number][$y_rotation], 
-## $obs[$obs_number][$tilt], $obs[$obs_number][$opacity], $obs[$obs_number][$material], 
-## EXAMPLE: $obs[2][$x] = 2. THIS MEANS: COORDINATE x OF OBSTRUCTION HAS TO BE SET TO 2.
-## OTHER EXAMPLE: $obs[2][$x] = $obs[2][$y]. THIS MEANS: 
-## NOTE: THE MATERIAL TO BE SPECIFIED IS A MATERIAL LETTER, BETWEEN QUOTES. EXAMPLE: $obs[1][$material] = "a".
-##  $tilt IS PRESENTLY UNUSED.
-## ALSO, THIS FILE MAKES AVAILABLE TO THE USER INFORMATIONS ABOUT THE MORPHING STEP OF THE MODELS 
-## AND THE STEPS THE MODEL HAVE TO FOLLOW. SPECIFICALLY, THE FOLLOWING VARIABLES:
-## $stepsvar, WHICH TELLS THE PROGRAM HOW MANY ITERATION STEPS IT HAS TO DO IN THE CURRENT MORPHING PHASE.
-## $counterzone, WHICH TELLS THE PROGRAM WHAT OPERATION IS BEING EXECUTED IN THE CHAIN OF OPERATIONS 
-## THAT MAY BE EXECUTES AT EACH MORPHING PHASE. EACH $counterzone WILL CONTAIN ONE OR MORE ITERATION STEPS.
-## TYPICALLY, IT WILL BE USED FOR A ZONE, BUT NOTHING PREVENTS THAT SEVERAL OF THEM CHAINED ONE AFTER 
-## THE OTHER ARE APPLIED TO THE SAME ZONE.
-## $counterstep, WHICH TELLS THE PROGRAM WHAT THE CURRENT ITERATION STEP IS.
-## If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
-## WITH THE FOLLOWING VARIABLE:  @obs_letters 
+# In the file for the propagation of constraints, the vertices are named for example like this:
+# $ver{1}{2}, which means: vertex 2 of zone 1.
+# $ver{1}{2}->[0] is the "x" value; $ver{1}{2}->[1] is the "y" value; $ver{1}{2}->[2] is the "z" value
+# the obstructions are named for example like this:
+# $obs{1}{2}, which means: vertex 2 of zone 1.
+# $obs{1}{2}->[0] is the "x" value of the position, ...[1] the "y", ...[2] the "z";
+# $obs{1}{2}->[4] is the width, ...[5] the depth, ...[6] the height, 
+# ...[7] the "y" rotation, ...[8] the tilt, ...[9] the opacity,
+# ...[10] the name, [11] the material.
 
 
 $vals{1}{111}{vary_controls} = 
